package ink.wgink.login.base.controller.route;

import ink.wgink.interfaces.consts.ISystemConstant;
import ink.wgink.interfaces.menu.IMenuBaseService;
import ink.wgink.interfaces.user.IUserCheckService;
import ink.wgink.login.base.config.properties.SystemProperties;
import ink.wgink.login.base.consts.IUserCenterConst;
import ink.wgink.login.base.manager.ConfigManager;
import ink.wgink.pojo.dtos.menu.MenuDTO;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.web.authentication.logout.SecurityContextLogoutHandler;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Objects;

/**
 * When you feel like quitting. Think about why you started
 * 当你想要放弃的时候，想想当初你为何开始
 *
 * @ClassName: LoginController
 * @Description: 登录
 * @Author: WangGeng
 * @Date: 2021/2/25 19:16
 * @Version: 1.0
 **/
@Controller
@RequestMapping("oauth")
public class OAuthRouteController {

    @Autowired
    private SystemProperties systemProperties;

    /**
     * 登录
     *
     * @return
     */
    @GetMapping("login")
    public ModelAndView login(HttpServletRequest request) {
        ModelAndView mv = new ModelAndView("login");
        mv.addObject(IUserCenterConst.SERVER_URL, systemProperties.getUrl());
        if (request.getParameter(IUserCenterConst.ERROR) != null) {
            mv.addObject(IUserCenterConst.ERROR_MESSAGE, request.getSession().getAttribute(IUserCenterConst.ERROR_MESSAGE));
        }
        Map<String, Object> config = ConfigManager.getInstance().getConfig();
        // 系统LOGO
        if (!Objects.isNull(config.get(IUserCenterConst.SYSTEM_LOGO)) && !StringUtils.isBlank(config.get(IUserCenterConst.SYSTEM_LOGO).toString())) {
            mv.addObject(IUserCenterConst.SYSTEM_LOGO, config.get(IUserCenterConst.SYSTEM_LOGO).toString());
        } else {
            mv.addObject(IUserCenterConst.SYSTEM_LOGO, "");
        }
        // 背景图片
        if (!Objects.isNull(config.get(IUserCenterConst.LOGIN_BACKGROUND_IMAGES)) && !StringUtils.isBlank(config.get(IUserCenterConst.LOGIN_BACKGROUND_IMAGES).toString())) {
            mv.addObject(IUserCenterConst.LOGIN_BACKGROUND_IMAGES, config.get(IUserCenterConst.LOGIN_BACKGROUND_IMAGES).toString());
        } else {
            mv.addObject(IUserCenterConst.LOGIN_BACKGROUND_IMAGES, "");
        }
        // 系统名称
        if (!Objects.isNull(config.get(IUserCenterConst.SYSTEM_NAME)) && !StringUtils.isBlank(config.get(IUserCenterConst.SYSTEM_NAME).toString())) {
            mv.addObject(IUserCenterConst.LOGIN_PAGE_NAME, config.get(IUserCenterConst.SYSTEM_NAME).toString());
        } else {
            mv.addObject(IUserCenterConst.LOGIN_PAGE_NAME, systemProperties.getLoginPageName());
        }
        // 系统名称大小
        if (!Objects.isNull(config.get(IUserCenterConst.SYSTEM_NAME_SIZE)) && Integer.parseInt(config.get(IUserCenterConst.SYSTEM_NAME_SIZE).toString()) > 12) {
            mv.addObject(IUserCenterConst.SYSTEM_NAME_SIZE, Integer.parseInt(config.get(IUserCenterConst.SYSTEM_NAME_SIZE).toString()));
        } else {
            mv.addObject(IUserCenterConst.SYSTEM_NAME_SIZE, 26);
        }
        // 系统标题
        if (!Objects.isNull(config.get(IUserCenterConst.SYSTEM_TITLE)) && !StringUtils.isBlank(config.get(IUserCenterConst.SYSTEM_TITLE).toString())) {
            mv.addObject(IUserCenterConst.SYSTEM_TITLE, config.get(IUserCenterConst.SYSTEM_TITLE).toString());
        } else {
            mv.addObject(IUserCenterConst.SYSTEM_TITLE, systemProperties.getTitle());
        }
        // 系统标题大小
        if (!Objects.isNull(config.get(IUserCenterConst.SYSTEM_TITLE_SIZE)) && Integer.parseInt(config.get(IUserCenterConst.SYSTEM_TITLE_SIZE).toString()) > 12) {
            mv.addObject(IUserCenterConst.SYSTEM_TITLE_SIZE, Integer.parseInt(config.get(IUserCenterConst.SYSTEM_TITLE_SIZE).toString()));
        } else {
            mv.addObject(IUserCenterConst.SYSTEM_TITLE_SIZE, 16);
        }
        // 版权年份
        if (!Objects.isNull(config.get(IUserCenterConst.COPY_RIGHT_YEAR))) {
            mv.addObject(IUserCenterConst.COPY_RIGHT_YEAR, config.get(IUserCenterConst.COPY_RIGHT_YEAR).toString());
        } else {
            mv.addObject(IUserCenterConst.COPY_RIGHT_YEAR, "");
        }
        // 版权所属
        if (!Objects.isNull(config.get(IUserCenterConst.COPY_LEFT))) {
            mv.addObject(IUserCenterConst.COPY_LEFT, config.get(IUserCenterConst.COPY_LEFT).toString());
        } else {
            mv.addObject(IUserCenterConst.COPY_LEFT, "");
        }
        // 官方链接
        if (!Objects.isNull(config.get(IUserCenterConst.OFFICIAL_URL))) {
            mv.addObject(IUserCenterConst.OFFICIAL_URL, config.get(IUserCenterConst.OFFICIAL_URL).toString());
        } else {
            mv.addObject(IUserCenterConst.OFFICIAL_URL, "");
        }
        // 开启验证码
        if (!Objects.isNull(config.get(ISystemConstant.VERIFICATION_CODE))) {
            mv.addObject(ISystemConstant.VERIFICATION_CODE, config.get(ISystemConstant.VERIFICATION_CODE).toString());
        } else {
            mv.addObject(ISystemConstant.VERIFICATION_CODE, ISystemConstant.IS_FALSE);
        }
        // 开启uKey登录
        if (!Objects.isNull(config.get(IUserCenterConst.UKEY_LOGIN))) {
            mv.addObject(IUserCenterConst.UKEY_LOGIN, config.get(IUserCenterConst.UKEY_LOGIN).toString());
        } else {
            mv.addObject(IUserCenterConst.UKEY_LOGIN, ISystemConstant.IS_FALSE);
        }
        // 开启扫码登录
        if (!Objects.isNull(config.get(IUserCenterConst.SCAN_CODE_LOGIN))) {
            mv.addObject(IUserCenterConst.SCAN_CODE_LOGIN, config.get(IUserCenterConst.SCAN_CODE_LOGIN).toString());
            // 钉钉扫码登陆APPID
//            if (!StringUtils.isBlank(dingDingScanCodeLoginProperties.getAppId())) {
//                mv.addObject(IUserCenterConst.DING_DING_SCAN_CODE_APP_ID, dingDingScanCodeLoginProperties.getAppId());
//            } else {
//                mv.addObject(IUserCenterConst.DING_DING_SCAN_CODE_APP_ID, "");
//            }
        } else {
            mv.addObject(IUserCenterConst.SCAN_CODE_LOGIN, ISystemConstant.IS_FALSE);
        }
        // 登录框位置
        if (!Objects.isNull(config.get(IUserCenterConst.LOGIN_BOX_POSITION))) {
            mv.addObject(IUserCenterConst.LOGIN_BOX_POSITION, config.get(IUserCenterConst.LOGIN_BOX_POSITION).toString());
        } else {
            mv.addObject(IUserCenterConst.LOGIN_BOX_POSITION, "default");
        }
        return mv;
    }

    /**
     * 登出
     *
     * @param request
     * @param response
     */
    @GetMapping("logout")
    public void logout(HttpServletRequest request, HttpServletResponse response) {
        new SecurityContextLogoutHandler().logout(request, null, null);
        try {
            response.sendRedirect(request.getHeader("referer"));
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

}
